# Install
```shell
pip install pymlfunc 
```

# List of functions
 - normxcorr2
 - tictoc (as context)


# Usage
```python
from pymlfunc import *

```

# Test
```shell
nosetests --nocapture -v
``` 
 
